package com.vetti.hotake.service;

import java.util.List;
import com.vetti.hotake.domain.HotakeCandidateInterviewRecordInfo;

/**
 * 候选人面试记录信息Service接口
 * 
 * @author wangxiangshun
 * @date 2025-12-08
 */
public interface IHotakeCandidateInterviewRecordInfoService 
{
    /**
     * 查询候选人面试记录信息
     * 
     * @param id 候选人面试记录信息主键
     * @return 候选人面试记录信息
     */
    public HotakeCandidateInterviewRecordInfo selectHotakeCandidateInterviewRecordInfoById(Long id);

    /**
     * 查询候选人面试记录信息列表
     * 
     * @param hotakeCandidateInterviewRecordInfo 候选人面试记录信息
     * @return 候选人面试记录信息集合
     */
    public List<HotakeCandidateInterviewRecordInfo> selectHotakeCandidateInterviewRecordInfoList(HotakeCandidateInterviewRecordInfo hotakeCandidateInterviewRecordInfo);

    /**
     * 新增候选人面试记录信息
     * 
     * @param hotakeCandidateInterviewRecordInfo 候选人面试记录信息
     * @return 结果
     */
    public int insertHotakeCandidateInterviewRecordInfo(HotakeCandidateInterviewRecordInfo hotakeCandidateInterviewRecordInfo);

    /**
     * 修改候选人面试记录信息
     * 
     * @param hotakeCandidateInterviewRecordInfo 候选人面试记录信息
     * @return 结果
     */
    public int updateHotakeCandidateInterviewRecordInfo(HotakeCandidateInterviewRecordInfo hotakeCandidateInterviewRecordInfo);

    /**
     * 批量删除候选人面试记录信息
     * 
     * @param ids 需要删除的候选人面试记录信息主键集合
     * @return 结果
     */
    public int deleteHotakeCandidateInterviewRecordInfoByIds(Long[] ids);

    /**
     * 删除候选人面试记录信息信息
     * 
     * @param id 候选人面试记录信息主键
     * @return 结果
     */
    public int deleteHotakeCandidateInterviewRecordInfoById(Long id);

    /**
     * 批量新增候选人面试记录信息
     *
     * @param hotakeCandidateInterviewRecordInfoList 候选人面试记录信息列表
     * @return 结果
     */
    public int batchInsertHotakeCandidateInterviewRecordInfo(List<HotakeCandidateInterviewRecordInfo> hotakeCandidateInterviewRecordInfoList);

}
